@@ -81,7 +81,7 @@
 #include "searchbar.h"
 #include "arkviewer.h"
 
-static void viewInExternalViewer( ArkWidget* parent, const QString& filename )
+static void viewInExternalViewer( ArkWidget* parent, const KURL& filename )
 {
     QString mimetype = KMimeType::findByURL( filename )->name();
     bool view = true;
@@ -207,6 +207,8 @@ ArkWidget::busy( const QString & text )
     if ( m_bBusy )
         return;
 
+    m_fileListView->setEnabled( false );
+
     QApplication::setOverrideCursor( waitCursor );
     m_bBusy = true;
 }
@@ -237,6 +239,8 @@ ArkWidget::ready()
     if ( !m_bBusy )
         return;
 
+    m_fileListView->setEnabled( true );
+
     QApplication::restoreOverrideCursor();
     emit setReady();
     m_bBusyHold = false;
@@ -851,10 +855,10 @@ ArkWidget::extractOnlyOpenDone()
 }
 
 void
-ArkWidget::slotExtractDone()
+ArkWidget::slotExtractDone(bool success)
 {
     disconnect( arch, SIGNAL( sigExtract( bool ) ),
-                this, SLOT( slotExtractDone() ) );
+                this, SLOT( slotExtractDone(bool) ) );
     ready();
 
     if(m_extractList != 0)
@@ -876,6 +880,11 @@ ArkWidget::slotExtractDone()
         emit request_file_quit();
     }
 
+    if ( success && ArkSettings::openDestinationFolder() )
+    {
+            KRun::runURL( m_extractURL, "inode/directory" );
+    }
+
     kdDebug(1601) << "-ArkWidget::slotExtractDone" << endl;
 }
 
@@ -1308,8 +1317,7 @@ ArkWidget::openWithSlotExtractDone()
             SLOT( openWithSlotExtractDone() ) );
 
     KURL::List list;
-    KURL url = m_strFileToView;
-    list.append(url);
+    list.append(m_viewURL);
     KOpenWithDlg l( list, i18n("Open with:"), QString::null, (QWidget*)0L);
     if ( l.exec() )
     {
@@ -1345,9 +1353,8 @@ ArkWidget::prepareViewFiles( const QStringList & fileList )
         it != fileList.end(); ++it)
         QFile::remove(destTmpDirectory + *it);
 
-    QStringList * list = new QStringList( fileList );
-    arch->unarchFile( list, destTmpDirectory, true);
-    delete list;
+    m_viewList = new QStringList( fileList );
+    arch->unarchFile( m_viewList, destTmpDirectory, true);
 }
 
 bool
@@ -1439,7 +1446,8 @@ ArkWidget::action_extract()
                          : QString();
 
     // Should the extraction dialog show an option for extracting only selected files?
-    bool enableSelected = ( m_nNumSelectedFiles > 0 );
+   bool enableSelected = ( m_nNumSelectedFiles > 0 ) &&
+        ( m_fileListView->totalFiles() > 1);
 
     QString base = ArkSettings::extractionHistory().isEmpty()?
                        QString() : ArkSettings::extractionHistory().first();
@@ -1511,7 +1519,7 @@ ArkWidget::action_extract()
                 {
                     disableAll();
                     busy( i18n( "Extracting..." ) );
-                    connect( arch, SIGNAL( sigExtract( bool ) ), this, SLOT( slotExtractDone() ) );
+                    connect( arch, SIGNAL( sigExtract( bool ) ), this, SLOT( slotExtractDone(bool) ) );
                     arch->unarchFile(0, extractDir);
                 }
             }
@@ -1539,15 +1547,11 @@ ArkWidget::action_extract()
                         disableAll();
                         busy( i18n( "Extracting..." ) );
                         connect( arch, SIGNAL( sigExtract( bool ) ),
-                                 this, SLOT( slotExtractDone() ) );
+                                 this, SLOT( slotExtractDone(bool) ) );
                         arch->unarchFile(m_extractList, extractDir); // extract selected files
                     }
                 }
         }
-        if ( dlg->viewFolderAfterExtraction() )
-        {
-            KRun::runURL( dlg->extractionDirectory(), "inode/directory" );
-        }
 
         delete dlg;
     }
@@ -1608,7 +1612,7 @@ ArkWidget::editStart()
     if ( l.exec() )
     {
         KProcess *kp = new KProcess;
-        m_strFileToView = m_strFileToView.right(m_strFileToView.length() - 5 );
+
         *kp << l.text() << m_strFileToView;
         connect( kp, SIGNAL(processExited(KProcess *)),
                 this, SLOT(slotEditFinished(KProcess *)) );
@@ -1689,23 +1693,26 @@ ArkWidget::viewSlotExtractDone( bool success )
         {
             ArkViewer * viewer = new ArkViewer( this, "viewer" );
 
-            if ( !viewer->view( m_strFileToView ) )
+            if ( !viewer->view( m_viewURL ) )
             {
                 QString text = i18n( "The internal viewer is not able to display this file. Would you like to view it using an external program?" );
                 view = ( KMessageBox::warningYesNo( this, text, QString::null, i18n("View Externally"), i18n("Do Not View") ) == KMessageBox::Yes );
 
                 if ( view )
-                    viewInExternalViewer( this, m_strFileToView );
+                    viewInExternalViewer( this, m_viewURL );
             }
         }
         else
         {
-            viewInExternalViewer( this, m_strFileToView );
+            viewInExternalViewer( this, m_viewURL );
         }
     }
 
     disconnect( arch, SIGNAL( sigExtract( bool ) ), this,
                 SLOT( viewSlotExtractDone( bool ) ) );
+
+    delete m_viewList;
+
     // avoid race condition, don't do updates if application is exiting
     if( m_fileListView )
     {
@@ -1724,17 +1731,21 @@ ArkWidget::showCurrentFile()
 
     QString name = m_fileListView->currentItem()->fileName();
 
-    QString fullname;
-    fullname = "file:";
-    fullname += tmpDir();
+    QString fullname = tmpDir();
     fullname += name;
 
-    kdDebug(1601) << "File to be viewed: " << fullname << endl;
+    if(fullname.contains("../"))
+        fullname.remove("../");
+
+    //Convert the QString filename to KURL to escape the bad characters
+    m_viewURL.setPath(fullname);
+
+    m_strFileToView = fullname;
+    kdDebug(1601) << "File to be extracted: " << m_viewURL << endl;
 
     QStringList extractList;
     extractList.append(name);
 
-    m_strFileToView = fullname;
     if (ArkUtils::diskHasSpace( tmpDir(), m_fileListView->currentItem()->fileSize() ) )
     {
         disableAll();
@@ -2031,9 +2042,9 @@ Arch * ArkWidget::getNewArchive( const QString & _fileName, const QString& _mime
         return NULL;
     }
 
-    if (!newArch->utilityIsAvailable())
+    if (!newArch->archUtilityIsAvailable())
     {
-        KMessageBox::error(this, i18n("The utility %1 is not in your PATH.\nPlease install it or contact your system administrator.").arg(newArch->getUtility()));
+        KMessageBox::error(this, i18n("The utility %1 is not in your PATH.\nPlease install it or contact your system administrator.").arg(newArch->getArchUtility()));
         return NULL;
     }
 
@@ -2143,9 +2154,9 @@ ArkWidget::openArchive( const QString & _filename )
         return;
     }
 
-    if (!newArch->utilityIsAvailable())
+    if (!newArch->unarchUtilityIsAvailable())
     {
-        KMessageBox::error(this, i18n("The utility %1 is not in your PATH.\nPlease install it or contact your system administrator.").arg(newArch->getUtility()));
+        KMessageBox::error(this, i18n("The utility %1 is not in your PATH.\nPlease install it or contact your system administrator.").arg(newArch->getUnarchUtility()));
         return;
     }
 
