@@ -128,7 +128,7 @@ protected slots:
     void slotOpen(Arch *, bool, const QString &, int);
     void slotCreate(Arch *, bool, const QString &, int);
     void slotDeleteDone(bool);
-    void slotExtractDone();
+    void slotExtractDone(bool);
     void slotExtractRemoteDone(KIO::Job *job);
     void slotAddDone(bool);
     void slotEditFinished(KProcess *);
@@ -258,6 +258,9 @@ private: // data
     // URL to extract to.
     KURL m_extractURL;
 
+     // URL to view
+    KURL m_viewURL;
+
     // the mimetype the user wants to open this archive as
     QString m_openAsMimeType;
 
@@ -307,6 +310,7 @@ private: // data
 
     QStringList mDragFiles;
     QStringList *m_extractList;
+    QStringList *m_viewList;
     KTempDir *m_tmpDir;
 };
 
