@@ -44,6 +44,7 @@
 #include <kio/global.h>
 #include <kfileitem.h>
 #include <kapplication.h>
+#include <kglobal.h>
 
 // ark includes
 #include "arkwidget.h"
@@ -63,7 +64,8 @@ CompressedFile::CompressedFile( ArkWidget *_gui, const QString & _fileName, cons
   m_tempDirectory->setAutoDelete( true );
   m_tmpdir = m_tempDirectory->name();
   initData();
-  verifyUtilityIsAvailable(m_archiver_program, m_unarchiver_program);
+  verifyCompressUtilityIsAvailable(m_archiver_program);
+  verifyUncompressUtilityIsAvailable(m_unarchiver_program);
 
   if (!QFile::exists(_fileName))
   {
@@ -129,9 +131,9 @@ void CompressedFile::initData()
     }
     if ( mimeType == "application/x-compress" )
     {
-        m_unarchiver_program = "uncompress";
-        m_archiver_program = "compress";
-        m_defaultExtensions = ".Z";
+        m_unarchiver_program = KGlobal::dirs()->findExe( "uncompress" ).isNull()? "gunzip" : "uncompress";
+        m_archiver_program   = "compress";
+        m_defaultExtensions  = ".Z";
     }
 
 }
