@@ -24,7 +24,7 @@
 
     You should have received a copy of the GNU General Public License
     along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 
 */
 
@@ -770,7 +770,7 @@ void CalcEngine::TangensGrad(KNumber input)
 
 void CalcEngine::TangensHyp(KNumber input)
 {
-	CALCAMNT tmp_num = input.toQString().toDouble();
+	CALCAMNT tmp_num = static_cast<double>(input);
 	_last_number = KNumber(double(TANH(tmp_num)));
 }
 
