@@ -913,7 +913,7 @@ int _knumfloat::compare(_knumber const &arg2) const
 
 
 
-_knumerror::operator long int (void) const
+_knumerror::operator signed long int (void) const
 {
   // what would be the correct return values here?
   if (_error == Infinity)
@@ -924,21 +924,48 @@ _knumerror::operator long int (void) const
     return 0;
 }
 
-_knuminteger::operator long int (void) const
+_knumerror::operator unsigned long int (void) const
+{
+  // what would be the correct return values here?
+  if (_error == Infinity)
+    return 0;
+  if (_error == MinusInfinity)
+    return 0;
+  else // if (_error == UndefinedNumber)
+    return 0;
+}
+
+
+_knuminteger::operator signed long int (void) const
 {
   return mpz_get_si(_mpz);
 }
 
-_knumfraction::operator long int (void) const
+_knumfraction::operator signed long int (void) const
 {
-  return static_cast<long int>(mpq_get_d(_mpq));
+  return static_cast<signed long int>(mpq_get_d(_mpq));
 }
 
-_knumfloat::operator long int (void) const
+_knumfloat::operator signed long int (void) const
 {
   return mpf_get_si(_mpf);
 }
 
+_knuminteger::operator unsigned long int (void) const
+{
+  return mpz_get_ui(_mpz);
+}
+
+_knumfraction::operator unsigned long int (void) const
+{
+  return static_cast<unsigned long int>(mpq_get_d(_mpq));
+}
+
+_knumfloat::operator unsigned long int (void) const
+{
+  return mpf_get_ui(_mpf);
+}
+
 
 
 _knumerror::operator double (void) const
