@@ -230,7 +230,8 @@ void KgpgInterface::readdecprocess(KProcIO *p)
                                 }
                                 p->writeStdin(passphrase,true);
                                 userIDs=QString::null;
-                                step--;
+                                if (step>1) step--;
+				else step=3;
                         } else {
                                 p->writeStdin("quit");
                                 p->closeWhenDone();
@@ -406,7 +407,8 @@ void KgpgInterface::getCmdOutput(KProcess *p, char *data, int )
 			passphrase.append("\n");
 			p->writeStdin(passphrase,passphrase.length());
 			userIDs=QString::null;
-			step--;
+			if (step>1) step--;
+			else step=3;
 		}
 		else
 		{
@@ -423,6 +425,7 @@ void KgpgInterface::getCmdOutput(KProcess *p, char *data, int )
 
 	if (required.find("END_DECRYPTION")!=-1) decfinished=true;
 	if (required.find("DECRYPTION_OKAY")!=-1) decok=true;
+	if (required.find("DECRYPTION_FAILED")!=-1) decok=false;
 	if (required.find("BADMDC")!=-1) badmdc=true;
 	}
 }
@@ -491,7 +494,8 @@ void KgpgInterface::txtsignprocess(KProcIO *p)
 	
 	if ((required.find("passphrase.enter")!=-1))
             {
-	      step--;
+	      if (step>1) step--;
+	      else step=3;
               if (userIDs.isEmpty())
                 userIDs=i18n("[No user id found]");
               QCString passphrase;
@@ -525,8 +529,9 @@ void KgpgInterface::KgpgDecryptFileToText(KURL srcUrl,QStringList Options)
 decfinished=false;
 decok=false;
 badmdc=false;
- KProcIO *proc=new KProcIO();
-	  *proc<<"gpg"<<"--no-tty"<<"--no-secmem-warning"<<"--command-fd=0"<<"--status-fd=1"<<"--no-batch"<<"-o"<<"-";
+
+  KProcess *proc=new KProcess();
+  *proc<<"gpg"<<"--no-tty"<<"--no-secmem-warning"<<"--command-fd=0"<<"--status-fd=2"<<"--no-batch"<<"-o"<<"-";
       	for ( QStringList::Iterator it = Options.begin(); it != Options.end(); ++it ) {
        		if (!QFile::encodeName(*it).isEmpty()) *proc<< QFile::encodeName(*it);
     		}
@@ -534,9 +539,10 @@ badmdc=false;
 
   /////////  when process ends, update dialog infos
 
-  QObject::connect(proc, SIGNAL(processExited(KProcess *)),this,SLOT(txtdecryptfin(KProcess *)));
-  QObject::connect(proc,SIGNAL(readReady(KProcIO *)),this,SLOT(txtreaddecprocess(KProcIO *)));
-  proc->start(KProcess::NotifyOnExit,false);
+  connect(proc, SIGNAL(processExited(KProcess *)),this,SLOT(txtdecryptfin(KProcess *)));
+  connect(proc, SIGNAL(receivedStdout(KProcess *, char *, int)),this, SLOT(getOutput(KProcess *, char *, int)));
+  connect(proc, SIGNAL(receivedStderr(KProcess *, char *, int)),this, SLOT(getCmdOutput(KProcess *, char *, int)));
+  proc->start(KProcess::NotifyOnExit,KProcess::All);
 }
 
 
@@ -607,7 +613,7 @@ QString required;
 
 Md5Widget::Md5Widget(QWidget *parent, const char *name,KURL url):KDialogBase( parent, name, true,i18n("MD5 Checksum"),Apply | Close)
 {
-        setButtonApplyText(i18n("Compare MD5 with Clipboard"));
+        setButtonApply(i18n("Compare MD5 with Clipboard"));
         mdSum=QString::null;
         QFile f(url.path());
         f.open( IO_ReadOnly);
@@ -744,7 +750,8 @@ void KgpgInterface::readsignprocess(KProcIO *p)
                                 }
                                 p->writeStdin(passphrase,true);
                                 userIDs=QString::null;
-                                step--;
+				if (step>1) step--;
+				else step=3;
                         } else {
                                 p->writeStdin("quit");
                                 p->closeWhenDone();
@@ -820,7 +827,7 @@ void KgpgInterface::verifyfin(KProcess *)
     }
     else {
     	if (KMessageBox::questionYesNo(0,i18n("<qt><b>Missing signature:</b><br>Key id: %1<br><br>"
-                                                      "Do you want to import this key from a keyserver?</qt>").arg(signID),file.fileName())==KMessageBox::Yes)
+                                                      "Do you want to import this key from a keyserver?</qt>").arg(signID),file.fileName(),QString::null, i18n("Import"), i18n("Do Not Import"))==KMessageBox::Yes)
     	emit verifyquerykey(signID);
     }
     emit verifyfinished();
@@ -1692,7 +1699,7 @@ void KgpgInterface::addphotoprocess(KProcIO *p)
                 }
 		
 		if (required.find("photoid.jpeg.size")!=-1)  {
-			if (KMessageBox::questionYesNo(0,i18n("This image is very large. Use it anyway?"))==KMessageBox::Yes)
+			if (KMessageBox::questionYesNo(0,i18n("This image is very large. Use it anyway?"), QString::null, i18n("Use Anyway"), i18n("Do Not Use"))==KMessageBox::Yes)
                         p->writeStdin("Yes");
 			else 
 			{
@@ -1844,6 +1851,35 @@ QString KgpgInterface::getGpgSetting(QString name,QString configFile)
         return QString::null;
 }
 
+QString KgpgInterface::getGpgMultiSetting(QString name,QString configFile)
+{
+// get GnuPG setting for item that can have multiple entries (eg. encrypt-to)
+
+QString parsedResult=QString::null;
+
+        name=name.stripWhiteSpace()+" ";
+        QFile qfile(QFile::encodeName(configFile));
+        if (qfile.open(IO_ReadOnly) && (qfile.exists())) {
+                QString result;
+                QTextStream t( &qfile );
+                result=t.readLine();
+                while (result!=NULL) {
+                        if (result.stripWhiteSpace().startsWith(name)) {
+                                result=result.stripWhiteSpace();
+                                result.remove(0,name.length());
+				if (parsedResult!=QString::null)
+				parsedResult+=" "+result.stripWhiteSpace();
+				else
+                                parsedResult+=result.stripWhiteSpace();
+                                //return result.section(" ",0,0);
+                        }
+                        result=t.readLine();
+                }
+                qfile.close();
+        }
+        return parsedResult;
+}
+
 void KgpgInterface::delGpgGroup(QString name, QString configFile)
 {
         QString textToWrite;
@@ -1860,7 +1896,7 @@ void KgpgInterface::delGpgGroup(QString name, QString configFile)
                                 if (result2.startsWith(name) && (result2.remove(0,name.length()).stripWhiteSpace().startsWith("=")))
                                         result=QString::null;
                         }
-                        textToWrite+=result+"\n";
+                       if (result!=QString::null) textToWrite+=result+"\n";
                         result=t.readLine();
                 }
                 qfile.close();
@@ -1998,7 +2034,7 @@ void KgpgInterface::setGpgSetting(QString name,QString value,QString url)
                                         result=QString::null;
                                 found=true;
                         }
-                        textToWrite+=result+"\n";
+                        if (result!=QString::null) textToWrite+=result+"\n";
                         result=t.readLine();
                 }
                 qfile.close();
@@ -2014,6 +2050,38 @@ void KgpgInterface::setGpgSetting(QString name,QString value,QString url)
 }
 
 
+void KgpgInterface::setGpgMultiSetting(QString name,QStringList values,QString url)
+{
+        name=name+" ";
+        QString textToWrite;
+        bool found=false;
+        QFile qfile(QFile::encodeName(url));
+
+        if (qfile.open(IO_ReadOnly) && (qfile.exists())) {
+                QString result;
+                QTextStream t( &qfile );
+                result=t.readLine();
+                while (result!=NULL) {
+                        if (!result.stripWhiteSpace().startsWith(name))
+				textToWrite+=result+"\n";
+                        result=t.readLine();
+                }
+                qfile.close();
+
+		while (!values.isEmpty())
+		{
+                        textToWrite+="\n"+name+" "+values.first();
+			values.pop_front();
+		}
+
+                if (qfile.open(IO_WriteOnly)) {
+                        QTextStream t( &qfile);
+                        t << textToWrite;
+                        qfile.close();
+                }
+        }
+}
+
 void KgpgInterface::setGpgBoolSetting(QString name,bool enable,QString url)
 {
         QString textToWrite;
@@ -2032,7 +2100,7 @@ void KgpgInterface::setGpgBoolSetting(QString name,bool enable,QString url)
                                         result=QString::null;
                                 found=true;
                         }
-                        textToWrite+=result+"\n";
+                       if (result!=QString::null) textToWrite+=result+"\n";
                         result=t.readLine();
                 }
                 qfile.close();
