@@ -62,7 +62,6 @@ private:
         QString keyServer,defaultServerList;
         QString defaultKeyServer;
 	QFont startFont;
-	KSimpleConfig *ks;
         bool useAgent;
         bool defaultUseAgent;
         bool encryptToAlways;
@@ -76,12 +75,15 @@ private:
         bool isDefault();
 
 private slots:
+	void checkAdditionalState(bool);
 	void slotAddKeyServer();
 	void slotDelKeyServer();
 	void slotDefaultKeyServer();
         void updateWidgets();
         void updateWidgetsDefault();
         void updateSettings();
+	void insertAlwaysKey();
+	void insertFileKey();
 
         void listkey();
         QString namecode(QString kid);
@@ -97,6 +99,7 @@ signals:
 	void homeChanged();
 	void refreshTrust(int, QColor);
 	void installShredder();
+	void reloadKeyList();
 };
 
 #endif // KGPGOPTIONS_H
