@@ -18,8 +18,8 @@
 
    You should have received a copy of the GNU Library General Public License
    along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-   Boston, MA 02111-1307, USA.
+   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+   Boston, MA 02110-1301, USA.
 
 */
 
@@ -109,7 +109,7 @@ bool GenericMonitor::retrieveVolume()
 			{
 				m_volume = reply;
 				kmix_error = false;
-				kmixWindow->send("minimize");
+				kmixWindow->send("hide");
 			}
 		}
 	}
@@ -179,7 +179,7 @@ bool GenericMonitor::retrieveMute()
 
 	DCOPReply reply = kmixClient->call("mute", 0);
 	if (reply.isValid())
-		m_volume = reply;
+		m_mute = reply;
 	else
 		kmix_error = true;
 
@@ -195,11 +195,11 @@ bool GenericMonitor::retrieveMute()
 			{
 				m_mute = reply;
 				kmix_error = false;
-				kmixWindow->send("minimize");
+				kmixWindow->send("hide");
 			}
 		}	else 
 		{
-			kmixWindow->send("minimize");
+			kmixWindow->send("hide");
 			kmix_error = true;
 		}
 	}
