@@ -12,8 +12,8 @@
  *
  *  You should have received a copy of the GNU Library General Public License
  *  along with this library; see the file COPYING.LIB.  If not, write to
- *  the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- *  Boston, MA 02111-1307, USA.
+ *  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ *  Boston, MA 02110-1301, USA.
  **/
 #ifdef QT_ONLY
   #include "compat.h"
@@ -42,7 +42,7 @@ UserDefinedRegExps::UserDefinedRegExps( QWidget *parent, const char *name )
   QVBoxLayout* lay = new QVBoxLayout( top, 6 );
   lay->setAutoAdd( true );
 
-  QLabel* label = new QLabel( i18n("Compound regular expression:"), top );
+  QLabel* label = new QLabel( i18n("Compound regular expressions:"), top );
 
   // This is to avoid that the label set the minimum width for the window.
   label->setMinimumSize(1,0);
@@ -89,7 +89,7 @@ void UserDefinedRegExps::createItems( const QString& _title, const QString& dir,
 {
   QString title = _title;
   if (_title == QString::fromLatin1("general"))
-	  title = i18n("general");
+	  title = i18n("General");
 
   QListViewItem* lvItem = new QListViewItem( _userDefined, title );
   lvItem->setOpen( true );
@@ -117,7 +117,7 @@ void UserDefinedRegExps::createItems( const QString& _title, const QString& dir,
 
     new WidgetWinItem( *it, regexp, usersRegExp, lvItem );
 
-    // Inserth the regexp into the list of compound regexps
+    // Insert the regexp into the list of compound regexps
     if ( regexp->type() == RegExp::COMPOUND ) {
       CompoundRegExp* cregexp = dynamic_cast<CompoundRegExp*>( regexp );
       if ( cregexp && cregexp->allowReplace() )
@@ -200,7 +200,7 @@ void UserDefinedRegExps::slotEdit( QListViewItem* item, const QPoint& pos )
       QString fileName = WidgetWinItem::path() + QString::fromLocal8Bit("/") + txt + QString::fromLocal8Bit(".regexp");
       QFileInfo finfo( fileName );
       if ( finfo.exists() ) {
-        int answer = KMessageBox::warningYesNo( this, i18n("<p>Overwrite named regular expression <b>%1</b>?</p>").arg(txt) );
+        int answer = KMessageBox::warningYesNo( this, i18n("<p>Overwrite named regular expression <b>%1</b>?</p>").arg(txt), QString::null, i18n("Overwrite"), i18n("Do Not Overwrite") );
         if ( answer != KMessageBox::Yes )
           return;
 
