@@ -78,15 +78,18 @@ karamba::karamba(QString fn, QString name, bool reloading, int instance,
     QTimer::singleShot(100, this, SLOT(killWidget()));
     return;
   }
+  // Add self to list of open themes
+  // This also updates instance number
+  karambaApp->addKaramba(this, reloading);
+
+  if(prettyName.isEmpty())
+    prettyName = QString("%1 - %2").arg(m_theme.name()).arg(m_instance);
+
   kdDebug() << "Starting theme: " << m_theme.name()
             << " pretty name: " << prettyName << endl;
   QString qName = "karamba - " + prettyName;
-  //QString qName = "karamba - " + m_theme.name();
   setName(qName.ascii());
 
-  //Add self to list of open themes
-  karambaApp->addKaramba(this, reloading);
-
   KDirWatch *dirWatch = new KDirWatch( this );
   connect(dirWatch, SIGNAL( dirty( const QString & ) ),
           SLOT( slotFileChanged( const QString & ) ) );
@@ -225,7 +228,6 @@ karamba::karamba(QString fn, QString name, bool reloading, int instance,
 
   systray = 0;
   foundKaramba = false;
-  dockBar = false;
   onTop = false;
   managed = false;
   fixedPosition = false;
@@ -249,7 +251,7 @@ karamba::karamba(QString fn, QString name, bool reloading, int instance,
 
   setBackgroundMode( NoBackground);
   if( !(onTop || managed))
-    lower();
+    KWin::lowerWindow( winId() );
 
   if( !parseConfig() )
   {
@@ -468,7 +470,6 @@ bool karamba::parseConfig()
           toggleLocked->setChecked( true );
           slotToggleLocked();
           toggleLocked->setEnabled(false);
-          dockBar = true;
         }
 
         if(lineParser.getBoolean("BOTTOMBAR"))
@@ -479,7 +480,6 @@ bool karamba::parseConfig()
           toggleLocked->setChecked( true );
           slotToggleLocked();
           toggleLocked->setEnabled(false);
-          dockBar = true;
         }
 
         if(lineParser.getBoolean("RIGHTBAR"))
@@ -490,7 +490,6 @@ bool karamba::parseConfig()
           toggleLocked->setChecked( true );
           slotToggleLocked();
           toggleLocked->setEnabled(false);
-          dockBar = true;
         }
 
         if(lineParser.getBoolean("LEFTBAR"))
@@ -500,7 +499,6 @@ bool karamba::parseConfig()
           toggleLocked->setChecked( true );
           slotToggleLocked();
           toggleLocked->setEnabled(false);
-          dockBar = true;
         }
 
         QString path = lineParser.getString("MASK");
@@ -544,7 +542,7 @@ bool karamba::parseConfig()
         QFileInfo info(path);
         if( info.isRelative())
           path = m_theme.path() +"/" + path;
-        (new karamba( path, false ))->show();
+        (new karamba( path, QString() ))->show();
       }
 
       if(lineParser.meter() == "<GROUP>")
@@ -757,15 +755,7 @@ bool karamba::parseConfig()
     {
       // Matthew Kay: set window type to "dock"
       // (plays better with taskbar themes this way)
-      if(dockBar)
-      {
-        KWin::setType(winId(), NET::Dock);
-      }
-      else
-      {
-        KWin::setType(winId(), NET::Normal);
-      }
-
+      KWin::setType(winId(), NET::Dock);
       #if defined(KDE_MAKE_VERSION)
         #if KDE_VERSION >= KDE_MAKE_VERSION(3,1,9)
           //KDE 3.2 addition for the always on top issues
@@ -831,15 +821,7 @@ void karamba::makePassive()
 
   // Matthew Kay: set window type to "dock" (plays better with taskbar themes
   // this way)
-  if(dockBar)
-  {
-    KWin::setType(winId(), NET::Dock);
-  }
-  else
-  {
-    KWin::setType(winId(), NET::Normal);
-  }
-
+  KWin::setType(winId(), NET::Dock);
   #if defined(KDE_MAKE_VERSION)
     #if KDE_VERSION >= KDE_MAKE_VERSION(3,1,9)
       //KDE 3.2 addition for the always on top issues
@@ -1256,7 +1238,7 @@ void karamba::setIncomingData(QString theme, QString obj)
    //dataStream << txt;
 
    //kapp->dcopClient()->send( app->dcopClient()->appId(), "KarambaIface", "themeNotify(QString,QString)", data );
- 
+
   DCOPClient *c = kapp->dcopClient();
   if (!c->isAttached())
     c->attach();
@@ -1276,7 +1258,7 @@ void karamba::callTheme(QString theme, QString txt)
    //dataStream << txt;
 
    //kapp->dcopClient()->send( app->dcopClient()->appId(), "KarambaIface", "themeNotify(QString,QString)", data );
- 
+
   DCOPClient *c = kapp->dcopClient();
   if (!c->isAttached())
     c->attach();
@@ -1404,7 +1386,7 @@ void karamba::mousePressEvent( QMouseEvent *e )
     if( toggleLocked -> isChecked() )
       passClick( e );
     if( !(onTop || managed))
-      lower();
+      KWin::lowerWindow( winId() );
   }
 }
 
@@ -1521,7 +1503,7 @@ void karamba::paintEvent ( QPaintEvent *e)
   {
     if( lowerTimer.elapsed() > 100 )
     {
-      this->lower();
+      KWin::lowerWindow( winId() );
       lowerTimer.restart();
     }
   }
@@ -1903,7 +1885,7 @@ void karamba::readProperties(KConfig* config)
 {
   //qDebug("karamba::readProperties");
   config->setGroup("session");
-  QString atheme = config->readEntry("theme","");
+  QString atheme = config->readEntry("theme");
 }
 
 //Register types of events that can be dragged on our widget
