@@ -245,7 +245,7 @@ void KarambaApplication::checkPreviousSession(KApplication &app,
   {
     KConfig* config = app.sessionConfig();
     config->setGroup("General Options");
-    QString restartThemes = config->readEntry("OpenThemes","");
+    QString restartThemes = config->readEntry("OpenThemes");
 
     //Get themes that were running
     lst = QStringList::split(QString(";"), restartThemes);
@@ -279,7 +279,7 @@ bool KarambaApplication::startThemes(QStringList &lst)
   {
     karamba *mainWin = 0;
 
-    mainWin = new karamba(*it , false);
+    mainWin = new karamba(*it , QString());
     mainWin->show();
     result = true;
   }
@@ -318,8 +318,9 @@ bool KarambaApplication::hasKaramba(karamba* k)
 bool KarambaApplication::lockKaramba()
 {
   QString file = QDir::home().absPath() + "/.superkaramba/.lock";
+  mode_t mode = S_IRUSR | S_IWUSR | S_IRGRP | S_IWGRP;
 
-  fd = open(file.ascii(), O_CREAT | O_RDWR);
+  fd = open(file.ascii(), O_CREAT | O_RDWR | O_TRUNC, mode);
   if (fd < 0)
   {
     qWarning("Open failed in lock.");
